==> localnews-merchant-integration-3.8.0-sources.jar: com/bxm/localnews/merchant/facade/ForumPostFeignService.java <==
package com.bxm.localnews.merchant.facade;

import com.bxm.localnews.merchant.dto.ForumPostBriefInfoDto;
import com.bxm.localnews.merchant.dto.ShareContentDTO;
import com.bxm.localnews.merchant.dto.TopicFacadeVO;
import com.bxm.localnews.merchant.facade.fallback.ForumPostFallbackFactory;
import com.bxm.localnews.merchant.vo.ForumBasicVo;
import com.bxm.localnews.merchant.vo.ForumPostVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 新闻服务的帖子对外接口
 *
 * @author liujia
 * @date 2020/05/12 10:49
 */
@Api(tags = "4-95 [内部]帖子接口")
@RequestMapping("facade/forumPost")
@FeignClient(value = "localnews-news", fallbackFactory = ForumPostFallbackFactory.class, primary = false)
public interface ForumPostFeignService {

    @ApiOperation(value = "4-95-10 根据id获取话题信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "话题ID", required = true),
    })
    @GetMapping(value = "getTopicById")
    ResponseEntity<TopicFacadeVO> getTopicById(Long id);

    @ApiOperation(value = "4-95-11 获取帖子简略信息,不走详情查询（太重了）")
    @ApiImplicitParam(name = "postId", value = "帖子ID", required = true)
    @GetMapping("lightweight")
    ResponseEntity<ForumPostBriefInfoDto> getPostWithoutDetail(@RequestParam("postId") Long postId);

    @ApiOperation(value = "4-95-12 根据id获取话题信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "帖子ID", required = true),
    })
    @GetMapping(value = "getForumPostById")
    ResponseEntity<ForumPostVo> getForumPostById(@RequestParam("id") Long id);

    @ApiOperation(value = "4-95-13 获取某个地区下的热门新闻帖子")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "areaCode", value = "地区编码")
    })
    @GetMapping("getTopPost")
    ResponseEntity<List<ShareContentDTO>> getTopPost(@RequestParam("areaCode") String areaCode);

    @ApiOperation(value = "4-95-1 生成帖子")
    @PostMapping("createPost")
    Boolean createPost(@RequestBody ForumBasicVo forumBasicVo);
}

==> localnews-merchant-integration-3.10.1-sources.jar: com/bxm/localnews/merchant/facade/ForumPostFeignService.java <==
package com.bxm.localnews.merchant.facade;

import com.bxm.localnews.merchant.dto.ForumPostBriefInfoDto;
import com.bxm.localnews.merchant.dto.ShareContentDTO;
import com.bxm.localnews.merchant.dto.TopicFacadeVO;
import com.bxm.localnews.merchant.facade.fallback.ForumPostFallbackFactory;
import com.bxm.localnews.merchant.vo.ForumBasicVo;
import com.bxm.localnews.merchant.vo.ForumPostVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 新闻服务的帖子对外接口
 *
 * @author liujia
 * @date 2020/05/12 10:49
 */
@Api(tags = "4-95 [内部]帖子接口")
@RequestMapping("facade/forumPost")
@FeignClient(value = "localnews-news", fallbackFactory = ForumPostFallbackFactory.class, primary = false)
public interface ForumPostFeignService {

    @ApiOperation(value = "4-95-10 根据id获取话题信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "话题ID", required = true),
    })
    @GetMapping(value = "getTopicById")
    ResponseEntity<TopicFacadeVO> getTopicById(Long id);

    @ApiOperation(value = "4-95-11 获取帖子简略信息,不走详情查询（太重了）")
    @ApiImplicitParam(name = "postId", value = "帖子ID", required = true)
    @GetMapping("lightweight")
    ResponseEntity<ForumPostBriefInfoDto> getPostWithoutDetail(@RequestParam("postId") Long postId);

    @ApiOperation(value = "4-95-12 根据id获取话题信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "帖子ID", required = true),
    })
    @GetMapping(value = "getForumPostById")
    ResponseEntity<ForumPostVo> getForumPostById(@RequestParam("id") Long id);

    @ApiOperation(value = "4-95-13 获取某个地区下的热门新闻帖子")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "areaCode", value = "地区编码")
    })
    @GetMapping("getTopPost")
    ResponseEntity<List<ShareContentDTO>> getTopPost(@RequestParam("areaCode") String areaCode);

    @ApiOperation(value = "4-95-1 生成帖子")
    @PostMapping("createPost")
    Boolean createPost(@RequestBody ForumBasicVo forumBasicVo);

    @ApiOperation(value = "4-95-19 根据帖子ID获取所属话题简略信息")
    @GetMapping("getTopicInfoByForumId")
    ResponseEntity<TopicFacadeVO> getTopicByForumId(@RequestParam("forumId") Long forumId);
}
